@@ -42,7 +42,7 @@ Target::~Target()
 
 void Target::freeResources()
 {
-	qDebug () << " free resources for " << this->id;
+	//qDebug () << " free resources for " << this->id;
 	if(picture) delete picture;
 	if(pictureBack) delete pictureBack;
 	picture = NULL;
@@ -59,7 +59,7 @@ void Target::freeResources()
 
 void Target::freeFieldList()
 {
-	qDebug () << " free list for " << this->id;
+	//qDebug () << " free list for " << this->id;
 	TargetField * field;
 	foreach(field,this->fields) {
 		delete field;
@@ -79,7 +79,7 @@ QString Target::getSummary () {
 	return this->type;
 }
 QImage * Target::getPictureSmall () {
-	//qDebug () << "getPictureSmall " << this->id << " " << pictureSmall;
+	////qDebug () << "getPictureSmall " << this->id << " " << pictureSmall;
 	if(!pictureSmall) {
 		QImage * orig = getPicture();
 
@@ -139,16 +139,16 @@ DatabaseManager::~DatabaseManager()
 //	else
 //		db.removeDatabase();
 
-	qDebug () << "CLOSE DB " << connectionName;
+	//qDebug () << "CLOSE DB " << connectionName;
 	if (db.isOpen()) {
-		qDebug () << "CLOSing DB";
+		//qDebug () << "CLOSing DB";
 		db.close();
 	}
 }
 
 bool DatabaseManager::isInit()
 {
-	qDebug () << "is init?";
+	//qDebug () << "is init?";
 
 
 	return db.tables().count() >= 3;
@@ -156,7 +156,7 @@ bool DatabaseManager::isInit()
 
 bool DatabaseManager::initDB()
 {
-	qDebug () << "INIT DB " << connectionName;
+	//qDebug () << "INIT DB " << connectionName;
 	bool ret = true;
 
 	// Create tables
@@ -178,7 +178,7 @@ bool DatabaseManager::initDB()
 bool DatabaseManager::migrateVersion (int fromV, int toV, const QString & pas) {
 	bool ret = true;
 
-	qDebug () << "MIGRATING DB VERSION FROM " << fromV << " TO " << toV;
+	//qDebug () << "MIGRATING DB VERSION FROM " << fromV << " TO " << toV;
 
 	if (fromV == 0 && toV == 1) {
 		if (backupDB ("BACK")) {
@@ -203,14 +203,14 @@ bool DatabaseManager::migrateVersion (int fromV, int toV, const QString & pas) {
 			ret = false;
 	}
 
-	qDebug () << "MIGRATED DB VERSION FROM " << fromV << " TO " << toV << " WITH RESULT " << ret;
+	//qDebug () << "MIGRATED DB VERSION FROM " << fromV << " TO " << toV << " WITH RESULT " << ret;
 
 	return ret;
 }
 
 bool DatabaseManager::deleteDB(const QString & prefix)
 {
-	qDebug () << "REMOVE DB " << connectionName;
+	//qDebug () << "REMOVE DB " << connectionName;
 	db.close();
 
 	QString path(QDir::home().path());
@@ -239,7 +239,7 @@ bool DatabaseManager::backupDB(const QString & prefix) {
 		dup = file.copy(pathBack);
 	}
 
-	qDebug () << "duplicate " << prefix << " DB " << dup;
+	//qDebug () << "duplicate " << prefix << " DB " << dup;
 
 	return dup;
 }
@@ -263,7 +263,7 @@ bool DatabaseManager::restoreDB(const QString & prefix) {
 		dup = fileBack.copy(path);
 	}
 
-	qDebug () << "restore " << prefix << " DB " << dup;
+	//qDebug () << "restore " << prefix << " DB " << dup;
 
 	return dup;
 }
@@ -280,29 +280,29 @@ bool DatabaseManager::migrationFrom (DatabaseManager * mgr) {
 	for (int i = 0; i < list.size (); i++) {
 		Target * target = list[i];
 
-		qDebug () << "MIGRATING " << target->name;
+		//qDebug () << "MIGRATING " << target->name;
 
 		mgr->getFields(target);
 
 		res = insertTarget(target);
 
-		qDebug () << "MIGRATING 1 " << target->name << res;
+		//qDebug () << "MIGRATING 1 " << target->name << res;
 		if (!res) return false;
 
 		if (target->getPicture() != NULL) {
 			res = updateTargetPicture (target);
-			qDebug () << "MIGRATING 2 " << target->name << res;
+			//qDebug () << "MIGRATING 2 " << target->name << res;
 			if (!res) return false;
 		}
 
 		if (target->getPictureBack() != NULL) {
 			res = updateTargetPictureBack (target);
-			qDebug () << "MIGRATING 3 " << target->name << res;
+			//qDebug () << "MIGRATING 3 " << target->name << res;
 			if (!res) return false;
 		}
 
 		res = updateFields (target);
-		qDebug () << "MIGRATING 4 " << target->name << res;
+		//qDebug () << "MIGRATING 4 " << target->name << res;
 		if (!res) return false;
 
 		target->freeFieldList();
@@ -313,7 +313,7 @@ bool DatabaseManager::migrationFrom (DatabaseManager * mgr) {
 }
 
 bool DatabaseManager::_openDB(const QString & name, const QString & cName) {
-	qDebug () << "OPEN DB " << name << "(" << cName << ")";
+	//qDebug () << "OPEN DB " << name << "(" << cName << ")";
 
 	connectionName = cName;
 
@@ -439,12 +439,12 @@ QString DatabaseManager::changePassword (const QString & newPassword) {
 				ret = oldDB->createPassword(newPassword, oldDB->currentVersion);
 				if (ret) {
 					if (oldDB->migrationFrom(this)) {
-						qDebug () << "succesfull migrated ";
+						//qDebug () << "succesfull migrated ";
 						db.close ();
 
 						ret = oldDB->restoreDB ("NEW");
 						if (ret) {
-							qDebug () << "succesfull changed ";
+							//qDebug () << "succesfull changed ";
 
 						}
 						else {
@@ -538,7 +538,7 @@ bool DatabaseManager::isReady () {
 
 bool DatabaseManager::checkPassword (QString _a, int version)
 {
-	qDebug () << "checkPassword " << version << "(" << connectionName << ")"; // << _a;
+	//qDebug () << "checkPassword " << version << "(" << connectionName << ")"; // << _a;
 
 	QByteArray t = _a.toLocal8Bit();
 	
@@ -574,7 +574,7 @@ bool DatabaseManager::checkPassword (QString _a, int version)
 
 bool DatabaseManager::createPassword (QString _a, int version)
 {
-	qDebug () << "createPassword " << version << "(" << connectionName << ")";
+	//qDebug () << "createPassword " << version << "(" << connectionName << ")";
 
 	QByteArray t = _a.toLocal8Bit();
 	
@@ -601,13 +601,13 @@ bool DatabaseManager::createPassword (QString _a, int version)
 		encryptSHA1(pp.mid(0, SHA1_LEN), a); // encrypt
 	}
 	
-	//qDebug () << "create secret " << a;
+	////qDebug () << "create secret " << a;
 	
 	return updateSecretPhrase (a);
 }
 
 bool DatabaseManager::updateSecretPhrase(QByteArray a) {
-	//qDebug () << "update secret " << a;
+	////qDebug () << "update secret " << a;
 
 	bool ret = false;
 	if (nextId () > 0) {
@@ -616,7 +616,7 @@ bool DatabaseManager::updateSecretPhrase(QByteArray a) {
 		if (ret) {
 			query.bindValue(":phrase", a);
 			ret = query.exec();
-			//qDebug () << "update secret " << ret;
+			////qDebug () << "update secret " << ret;
 			return ret;
 		}
 	}
@@ -625,7 +625,7 @@ bool DatabaseManager::updateSecretPhrase(QByteArray a) {
 
 bool DatabaseManager::hasSecretPhrase()
 {
-	qDebug () << "has secret?";
+	//qDebug () << "has secret?";
 	
 	QSqlQuery query("select phrase from id", db);
 	if (query.next()) {
@@ -637,7 +637,7 @@ bool DatabaseManager::hasSecretPhrase()
 
 QByteArray DatabaseManager::selectSecretPhrase()
 {
-	qDebug () << "get secret?";
+	//qDebug () << "get secret?";
 
 	QByteArray ret;
 	QSqlQuery query("select phrase from id", db);
@@ -855,7 +855,7 @@ bool DatabaseManager::insertTarget(Target* target)
 		if (ret) {
 			// http://www.sqlite.org/c3ref/last_insert_rowid.html
 			target->id = query.lastInsertId().toInt();
-			qDebug () << "INSERT " << target->id;
+			//qDebug () << "INSERT " << target->id;
 
 		}
 	}
@@ -918,7 +918,7 @@ bool DatabaseManager::deleteTarget(Target * target)
 		if (ret) {
 			ret = query.prepare("delete from targets where id=:code");
 			if (ret) {
-				qDebug () << "DELETE " << target->id;
+				//qDebug () << "DELETE " << target->id;
 
 				query.bindValue(":code", target->id);
 				ret = query.exec();
@@ -971,7 +971,7 @@ bool DatabaseManager::updateTarget(Target* target)
 			query.bindValue(":code", target->id);
 			ret = query.exec();
 
-			qDebug () << "updated " << target->id;
+			//qDebug () << "updated " << target->id;
 
 		}
 	}
@@ -985,7 +985,7 @@ bool DatabaseManager::updateTargetPicture(Target* target)
 		QSqlQuery query (db);
 		ret = query.prepare("UPDATE targets set picture=:picture where id=:code");
 		if (ret) {
-			qDebug () << "updating image " << target->id << " " << target->picture;
+			//qDebug () << "updating image " << target->id << " " << target->picture;
 
 			QByteArray im1;
 			QBuffer buffer1(&im1);
@@ -999,7 +999,7 @@ bool DatabaseManager::updateTargetPicture(Target* target)
 				query.bindValue(":picture", im_r1);
 			}
 			else {
-				qDebug () << "delete image ";
+				//qDebug () << "delete image ";
 
 				query.bindValue(":picture", QVariant (QVariant::ByteArray));
 			}
@@ -1007,7 +1007,7 @@ bool DatabaseManager::updateTargetPicture(Target* target)
 			query.bindValue(":code", target->id);
 			ret = query.exec();
 
-			qDebug () << "update picturde " << target->id;
+			//qDebug () << "update picturde " << target->id;
 
 		}
 	}
@@ -1021,7 +1021,7 @@ bool DatabaseManager::updateTargetPictureBack(Target* target)
 		QSqlQuery query (db);
 		ret = query.prepare("UPDATE targets set pictureBack=:pictureBack where id=:code");
 		if (ret) {
-			qDebug () << "UPDATE " << target->id << " " << target->name << " " << target->type;
+			//qDebug () << "UPDATE " << target->id << " " << target->name << " " << target->type;
 			QByteArray im2;
 			QBuffer buffer2(&im2);
 			QByteArray im_r2;
@@ -1041,7 +1041,7 @@ bool DatabaseManager::updateTargetPictureBack(Target* target)
 			query.bindValue(":code", target->id);
 			ret = query.exec();
 			
-			qDebug () << "update picture back" << target->id;
+			//qDebug () << "update picture back" << target->id;
 
 		}
 	}
@@ -1124,7 +1124,7 @@ void DatabaseManager::getFields(Target * target)
 {
 	if (target->listLoaded) return;
 
-	qDebug () << "get Fields for " << target->id;
+	//qDebug () << "get Fields for " << target->id;
 
 	//target->freeFieldList ();
 	
@@ -1169,9 +1169,9 @@ QImage * DatabaseManager::getPicture (Target * target) {
 			QByteArray im_s;
 			decrypt(query.value(0).toByteArray(), im_s);
 			if (!result->loadFromData (im_s)) {
-				qDebug () << "Error loading image " << target->id;
+				//qDebug () << "Error loading image " << target->id;
 			} else {
-				qDebug () << "loaded image " << target->id;
+				//qDebug () << "loaded image " << target->id;
 			}
 		}
 		break;
@@ -1194,10 +1194,10 @@ QImage * DatabaseManager::getPictureBack (Target * target) {
 			QByteArray im_s;
 			decrypt(query.value(0).toByteArray(), im_s);
 			if (!result->loadFromData (im_s)) {
-				qDebug () << "Error loading back image " << target->id;
+				//qDebug () << "Error loading back image " << target->id;
 			}
 			else {
-				//qDebug () << "loaded back image " << target->id;
+				////qDebug () << "loaded back image " << target->id;
 			}
 		}
 		break;
