@@ -23,14 +23,14 @@ public:
 protected:
 	bool isLabel;
     void mousePressEvent(QMouseEvent *ev) {
-    	//qDebug () << "click on field " << this->userData(0);
+    	////qDebug () << "click on field " << this->userData(0);
     	TargetField * f = ((ButtonInfo *)this->userData(0))->field;
     	if (f->type == TYPE_URL && !isLabel) {
     		QDesktopServices::openUrl(QUrl::fromUserInput(f->value));
     	}
     	else {
 			//if (f != NULL)
-			//qDebug () << "pressed " << f->value;
+			////qDebug () << "pressed " << f->value;
 			QClipboard *cb = QApplication::clipboard();
 			cb->setText(f->value);
     	}
@@ -53,7 +53,7 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 	this->parent = paTarget;
 	this->edit = edit;
 
-	qDebug () << "DETAIL " << target << " " << groupName << " " << istemplate << " " << edit;
+	//qDebug () << "DETAIL " << target << " " << groupName << " " << istemplate << " " << edit;
 
 	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
 
@@ -86,7 +86,7 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 		changeFields (0);
 	}
 
-	qDebug () << " going to " << edit << " " << (isNew ? "NEW" : this->target->name);
+	//qDebug () << " going to " << edit << " " << (isNew ? "NEW" : this->target->name);
 
 	orgType = this->target->type;
 
@@ -331,7 +331,7 @@ void DetailWindow::modifyFields() {
 		createFieldDlg->setMinimumSize(size().width(),size().height()-100);
 		createFieldDlg->exec();
 
-		//qDebug () << "NOW ";
+		////qDebug () << "NOW ";
 
 		showFields ();
 
@@ -345,21 +345,16 @@ void DetailWindow::addField (TargetField * field) {
 	target->fields.append(field);
 
 	_addField (field);
+	pos++;
 }
 
 void DetailWindow::_addField (TargetField * field) {
-	int s = 1;
-	if (field->type == TYPE_TEXT) {
-		s = 10;
-	}
-
-	//qDebug () << "trying to show " << field->name << " v=" << field->value << " t=" << field->type;
+	////qDebug () << "trying to show " << field->name << " v=" << field->value << " t=" << field->type;
 
 	QLineEdit * nameLabel = new QLineEdit(this);
-	//nameLabel->setContextMenuPolicy(Qt::NoContextMenu);
-	componentLayout->addWidget(nameLabel, pos + 1, 1, 1, 2);
 	nameLabel->setText (field->name);
 	nameLabel->setInputMethodHints(Qt::ImhNoAutoUppercase | Qt::ImhNoPredictiveText);
+	componentLayout->addWidget(nameLabel, pos, 0, 1, 1);
 	this->labels.append (nameLabel);
 
 	//ButtonInfo * info = new ButtonInfo (field);
@@ -367,53 +362,50 @@ void DetailWindow::_addField (TargetField * field) {
 
 	if (field->type == TYPE_TEXT) {
 		QTextEdit * nameLineEdit = new QTextEdit(this);
-		componentLayout->addWidget(nameLineEdit, pos + 1, 3, s, 4);
-		nameLineEdit->setText (field->value);
-		nameLineEdit->setInputMethodHints(Qt::ImhNoAutoUppercase | Qt::ImhNoPredictiveText);
+		nameLineEdit->setPlainText (field->value);
+		//nameLineEdit->setInputMethodHints(Qt::ImhNoAutoUppercase | Qt::ImhNoPredictiveText);
+		//nameLineEdit->setLineWrapColumnOrWidth(40);
 		this->values.append (nameLineEdit);
-		//nameLineEdit->setUserData(0,info);
+		componentLayout->addWidget(nameLineEdit, pos, 1, 1, 1);
+		componentLayout->setRowMinimumHeight(pos, 300);
 	}
 	else
 	if (field->type == TYPE_PASSWORD) {
 		QLineEdit * nameLineEdit = new QLineEdit(this);
-		componentLayout->addWidget(nameLineEdit, pos + 1, 3, s, 4);
 		nameLineEdit->setText (field->value);
 		nameLineEdit->setInputMethodHints(Qt::ImhNoAutoUppercase | Qt::ImhNoPredictiveText);
 		this->values.append (nameLineEdit);
-		//nameLineEdit->setUserData(0,info);
+		componentLayout->addWidget(nameLineEdit, pos, 1, 1, 1);
 	}
 	else
 	if (field->type == TYPE_INTEGER) {
 		QLineEdit * nameLineEdit = new QLineEdit(this);
-		componentLayout->addWidget(nameLineEdit, pos + 1, 3, s, 4);
 		nameLineEdit->setText (field->value);
 		nameLineEdit->setInputMethodHints(Qt::ImhDigitsOnly);
 		this->values.append (nameLineEdit);
-		//nameLineEdit->setUserData(0,info);
+		componentLayout->addWidget(nameLineEdit, pos, 1, 1, 1);
 	}
 	else
 	if (field->type == TYPE_DATE) {
 		QLineEdit * nameLineEdit = new QLineEdit(this);
-		componentLayout->addWidget(nameLineEdit, pos + 1, 3, s, 4);
 		nameLineEdit->setText (field->value);
 		nameLineEdit->setInputMethodHints(Qt::ImhNoAutoUppercase | Qt::ImhNoPredictiveText);
 		this->values.append (nameLineEdit);
-		//nameLineEdit->setUserData(0,info);
+		componentLayout->addWidget(nameLineEdit, pos, 1, 1, 1);
 	}
 	else
 	if (field->type == TYPE_PHONE_NUMBER) {
 		QLineEdit * nameLineEdit = new QLineEdit(this);
-		componentLayout->addWidget(nameLineEdit, pos + 1, 3, s, 4);
 		nameLineEdit->setText (field->value);
 		nameLineEdit->setInputMethodHints(Qt::ImhDigitsOnly);
-		//nameLineEdit->setInputMethodHints(Qt::ImhDialableCharactersOnly);
+		componentLayout->addWidget(nameLineEdit, pos, 1, 1, 1);
 		this->values.append (nameLineEdit);
 
 	}
 	else
 	if (field->type == TYPE_URL) {
 		QLineEdit * nameLineEdit = new QLineEdit(this);
-		componentLayout->addWidget(nameLineEdit, pos + 1, 3, s, 4);
+		componentLayout->addWidget(nameLineEdit, pos, 1, 1, 1);
 		nameLineEdit->setText (field->value);
 		//nameLineEdit->setInputMethodHints(Qt::ImhUrlCharactersOnly);
 		nameLineEdit->setInputMethodHints(Qt::ImhNoAutoUppercase | Qt::ImhNoPredictiveText);
@@ -421,7 +413,7 @@ void DetailWindow::_addField (TargetField * field) {
 	}
 	else {
 		QLineEdit * nameLineEdit = new QLineEdit(this);
-		componentLayout->addWidget(nameLineEdit, pos + 1, 3, s, 4);
+		componentLayout->addWidget(nameLineEdit, pos, 1, 1, 1);
 		//nameLineEdit->setCompleter(NULL);
 		nameLineEdit->setInputMethodHints(Qt::ImhNoAutoUppercase | Qt::ImhNoPredictiveText);
 		nameLineEdit->setText (field->value);
@@ -430,7 +422,7 @@ void DetailWindow::_addField (TargetField * field) {
 		//nameLineEdit->setUserData(0,info);
 	}
 
-	//qDebug () << "SHOWN " << field->name << " v=" << field->value << " t=" << field->type;
+	////qDebug () << "SHOWN " << field->name << " v=" << field->value << " t=" << field->type;
 }
 
 void DetailWindow::showFields () {
@@ -456,14 +448,13 @@ void DetailWindow::showFields () {
 		QObject::connect(signalMapper, SIGNAL(mapped(QWidget *)), this, SLOT(clickPass(QWidget *)));
 	}
 
+	componentLayout->setColumnStretch(0, 10);
+	componentLayout->setColumnStretch(1, 25);
+
 	pos = 0;
 	if (target) {
 		TargetField * field;
 		foreach(field, target->fields) {
-			int s = 1;
-			if (field->type == TYPE_TEXT) {
-				s = 10;
-			}
 			if (edit) {
 				_addField (field);
 			}
@@ -476,12 +467,12 @@ void DetailWindow::showFields () {
 
 					nameLabel->setUserData(0, new ButtonInfo (field));
 
-					componentLayout->addWidget(nameLabel, pos + 1, 1, 1, 2);
+					componentLayout->addWidget(nameLabel, pos, 0, 1, 1);
 
 					if (field->type == TYPE_PASSWORD) {// || field->name.contains("password", Qt::CaseInsensitive)) {
 						QPushButton * nameLineEdit = new QPushButton(tr("Click to see"), this);
 						//nameLineEdit->setContextMenuPolicy(Qt::NoContextMenu);
-						componentLayout->addWidget(nameLineEdit, pos + 1, 3, s, 2);
+						componentLayout->addWidget(nameLineEdit, pos, 1, 1, 1);
 
 						nameLineEdit->setUserData(0, new ButtonInfo (field)); //ObjectName(field->value);
 						signalMapper->setMapping(nameLineEdit, nameLineEdit);
@@ -489,31 +480,38 @@ void DetailWindow::showFields () {
 						QObject::connect(nameLineEdit, SIGNAL(clicked()), signalMapper, SLOT(map()));
 					}
 					else {
-						QLabel * nameLineEdit = new QLabelW(field->value, false, this);
-						nameLineEdit->setUserData(0, new ButtonInfo (field));
-						componentLayout->addWidget(nameLineEdit, pos + 1, 3, s, 4);
-//						if (field->type == TYPE_URL) {
-//							nameLineEdit->setFoStyle(QStyle::)
-//						}
+						if (field->type == TYPE_TEXT) {
+							QLabel * nameLineEdit = new QLabelW(field->value, false, this);
+							nameLineEdit->setUserData(0, new ButtonInfo (field));
+							nameLineEdit->setWordWrap(true);
+							componentLayout->addWidget(nameLineEdit, pos, 1, 1, 1);
+							//componentLayout->setRowMinimumHeight(pos, 300);
+						}
+						else {
+							QLabel * nameLineEdit = new QLabelW(field->value, false, this);
+							nameLineEdit->setUserData(0, new ButtonInfo (field));
+							nameLineEdit->setWordWrap(true);
+							componentLayout->addWidget(nameLineEdit, pos, 1, 1, 1);
+						}
 					}
 				}
 			}
-			pos += s;
+			pos++;
 		}
 
 	}
 
-	//qDebug () << " shown " << pos << " rows";
+	////qDebug () << " shown " << pos << " rows";
 	if (pos < 20) {
-		componentLayout->addItem(new QSpacerItem(1,20 - pos), pos + 1, 1, 20-pos, 6);
-		//qDebug () << " add " << (20 - pos) << " rows";
+		componentLayout->addItem(new QSpacerItem(1,20 - pos), pos, 0, 20-pos, 2);
+		////qDebug () << " add " << (20 - pos) << " rows";
 	}
 }
 
 void DetailWindow::clickPass (QWidget * _wid) {
 	QPushButton * b = (QPushButton *)_wid;
 
-	//qDebug () << "click on field " << b->userData(0);
+	////qDebug () << "click on field " << b->userData(0);
 
 	TargetField * f = ((ButtonInfo *)b->userData(0))->field;
 
@@ -528,18 +526,19 @@ void DetailWindow::clickPass (QWidget * _wid) {
 void DetailWindow::changeFields (int a) {
 	typeChanged = true;
 
-	qDebug () << "selected type " << a;
+	//qDebug () << "selected type " << a;
 
 	for (int i = target->fields.size(); i > 0; i--) {
 		TargetField * field = target->fields [i - 1];
 
 		if (field->value.length() == 0) {
-			qDebug () << "remove" << field->name;
+			//qDebug () << "remove" << field->name;
 			target->fields.removeAt(i - 1);
 			delete field;
 		}
-		else
-			qDebug () << "keep" << field->name;
+		else {
+			//qDebug () << "keep" << field->name;
+		}
 	}
 
 	for (int i = 0; i < parent->fieldsByType->at (a)->size(); i++) {
@@ -599,33 +598,33 @@ void DetailWindow::saveTarget () {
 	this->target->groupName = groupLineEdit->text();
 	this->target->type = typeLineEdit->itemData(typeLineEdit->currentIndex()).toString();
 	
-	//qDebug () << "getting fields ";
+	////qDebug () << "getting fields ";
 
 	for (int i = 0; i < target->fields.count(); i++) {
 		TargetField * field = target->fields[i];
-		qDebug () << "getting field " << i;
+		//qDebug () << "getting field " << i;
 		
 		field->name = labels[i]->text();
 		if (field->type == TYPE_TEXT) {
-			qDebug () << "getting TEX field " << i;
+			//qDebug () << "getting TEX field " << i;
 			field->value = ((QTextEdit*)values[i])->toPlainText();
 		}
 		else {
-			qDebug () << "getting LIN field " << i;
+			//qDebug () << "getting LIN field " << i;
 			field->value = ((QLineEdit*)values[i])->text();
 		}
 	}
-	qDebug () << "updating target";
+	//qDebug () << "updating target";
 	if (isNew) {
 		parent->_insertTarget(this->target);
 	}
 	else {
 		parent->_updateTarget(this->target);
 	}
-	qDebug () << "updating target face";
+	//qDebug () << "updating target face";
 
 	if (deleteFace) {
-		qDebug () << "DELETE FACE";
+		//qDebug () << "DELETE FACE";
 		target->setPicture (NULL);
 		parent->_updateTargetPicture(target);
 	}
@@ -641,10 +640,10 @@ void DetailWindow::saveTarget () {
 		}
 	}
 
-	qDebug () << "updating target back";
+	//qDebug () << "updating target back";
 
 	if (deleteBack) {
-		qDebug () << "DELETE BACK";
+		//qDebug () << "DELETE BACK";
 		target->setPictureBack (NULL);
 		parent->_updateTargetPictureBack(target);
 	}
@@ -655,13 +654,13 @@ void DetailWindow::saveTarget () {
 		parent->_updateTargetPictureBack(target);
 	}
 
-	qDebug () << "end updating ";
+	//qDebug () << "end updating ";
 
 	target->freeResources();
 	if (currentImageBackN) delete currentImageBackN;
 	if (currentImageN) delete currentImageN;
 
-	qDebug () << "clse ";
+	//qDebug () << "clse ";
 
 	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
 
@@ -719,7 +718,7 @@ void DetailWindow::loadImage (QString q, QImage& res) {
 	reader.setScaledSize(ss);
 	// Read image
 	res = reader.read();
-	//qDebug () << "read " << q << " as (" << imageSize << ") with result " << reader.errorString ();
+	////qDebug () << "read " << q << " as (" << imageSize << ") with result " << reader.errorString ();
 }
 
 void DetailWindow::cardMenu(const QPoint & _p) {
@@ -790,14 +789,14 @@ void DetailWindow::cardFace()
 	                tr("Images (*.png *.jpg *.gif *.jpeg);;"));
 
 	if (!s.isNull () && !s.isEmpty ()) {
-		//qDebug () << "loading " << s;
+		////qDebug () << "loading " << s;
 		if (currentImageN) delete currentImageN;
 
 		currentImageN = new QImage ();
 		loadImage(s, *currentImageN); //;
-		//qDebug () << "loaded " << s;
+		////qDebug () << "loaded " << s;
 		imageLabel->setPixmap(QPixmap::fromImage (*currentImageN));
-		//qDebug () << "asigned " << s;
+		////qDebug () << "asigned " << s;
 		//update();
 		deleteFace = false;
 	}
@@ -835,11 +834,11 @@ void DetailWindow::mirrorBack () {
 	}
 }
 //void DetailWindow::contextMenuEvent (QContextMenuEvent * event) {
-//	qDebug () << "NOW";
+//	//qDebug () << "NOW";
 //}
 //void DetailWindow::cardBackMenu(const QPoint & pos) {
 //
-//	//qDebug () << "MENU";
+//	////qDebug () << "MENU";
 //
 //	QMenu menu(this);
 //	if (edit) {
@@ -854,7 +853,7 @@ void DetailWindow::mirrorBack () {
 //}
 //void DetailWindow::cardFaceMenu(const QPoint & pos) {
 //
-//	//qDebug () << "MENU";
+//	////qDebug () << "MENU";
 //
 //	QMenu menu(this);
 //	if (edit) {
@@ -869,7 +868,7 @@ void DetailWindow::mirrorBack () {
 //}
 
 void DetailWindow::orientationChanged(int o) {
-	//qDebug () << "CHAGNED";
+	////qDebug () << "CHAGNED";
 
 	if (!edit) {
 		QRect screenGeometry = QApplication::desktop()->screenGeometry();
@@ -928,7 +927,7 @@ void DetailWindow::cardBack()
 	                path,
 	                tr("Images (*.png *.jpg *.gif *.jpeg);;"));
 	if (!s.isNull () && !s.isEmpty ()) {
-		//qDebug () << "loading " << s;
+		////qDebug () << "loading " << s;
 		if (currentImageBackN) delete currentImageBackN;
 		
 		currentImageBackN = new QImage ();
@@ -941,7 +940,7 @@ void DetailWindow::cardBack()
 }
 
 void DetailWindow::closeEvent(QCloseEvent *event) {
-	qDebug () << "close event";
+	//qDebug () << "close event";
 	if ((!forceClose) && (edit || isNew)) {
 		bool isModified = false;
 
@@ -950,11 +949,11 @@ void DetailWindow::closeEvent(QCloseEvent *event) {
 		for (int i = 0; (!isModified) && (i < target->fields.count()); i++) {
 			TargetField * field = target->fields[i];
 			if (field->type == TYPE_TEXT) {
-				qDebug () << "getting TEX field " << i;
+				//qDebug () << "getting TEX field " << i;
 				isModified |= ((QTextEdit*)values[i])->document ()->isModified ();
 			}
 			else {
-				qDebug () << "getting LIN field " << i;
+				//qDebug () << "getting LIN field " << i;
 				isModified |= ((QLineEdit*)values[i])->isModified();
 			}
 		}
