@@ -6,6 +6,21 @@
 #include "LoginDialog.h"
 #include "Constants.h"
 
+QLabelZ::QLabelZ(const QString &text, QWidget *parent=0, Qt::WindowFlags f=0) : QLabel (text, parent, f) {
+//	QPixmap available(":/resources/number.png");
+//	setPixmap(available);
+}
+QLabelZ::QLabelZ(QWidget *parent=0, Qt::WindowFlags f=0): QLabel (parent, f) {
+}
+QLabelZ::~QLabelZ() {
+}
+
+void QLabelZ::mousePressEvent(QMouseEvent *ev) {
+   	//qDebug () << "click on field " << this->userData(0);
+   	emit clicked ();
+//    	TargetField * f = ((ButtonInfo *)this->userData(0))->field;
+}
+
 LoginDialog::LoginDialog(bool firstTime, eWallet *paTarget): QWidget((QWidget*)paTarget)
 {
 	setContextMenuPolicy(Qt::NoContextMenu);
@@ -14,7 +29,7 @@ LoginDialog::LoginDialog(bool firstTime, eWallet *paTarget): QWidget((QWidget*)p
 	NTimes = 0;
 
 	QHBoxLayout * layout = new QHBoxLayout(this);
-	QGridLayout * componentLayout = new QGridLayout ();
+	componentLayout = new QGridLayout ();
 	this->parent = paTarget;
 
 	layout->setSpacing(0);
@@ -32,32 +47,31 @@ LoginDialog::LoginDialog(bool firstTime, eWallet *paTarget): QWidget((QWidget*)p
 	label->setMaxLength(16); //  |
 	//label->setAlignment(Qt::AlignCenter);
 
+	componentLayout->setSpacing(5);
+
 	for (int i = 0; i < 12; i++) {
 		QString text ('0' + i + 1);
 
+		componentLayout->setColumnMinimumWidth(i % 3, B_SIZE);
+		componentLayout->setRowMinimumHeight(i / 3, B_SIZE);
+
 		if (i == 9) {
 			text = tr("Ok");
-			imageButton[i] = new QPushButton(text, this); // QIcon(":/resources/icon_accept.png"),
-			//imageButton[i] ->setFixedSize(80, 80);
-			imageButton[i] ->setContextMenuPolicy(Qt::NoContextMenu);
-			imageButton[i] ->setFocusPolicy(Qt::NoFocus);
-			imageButton[i] ->setFont(QFont ("Arial", 22, 2, false));
-			//imageButton[i] ->setIconSize(QSize(20, 20));
-			componentLayout->addWidget(imageButton[i], i / 3, i % 3, 1, 1);
-
-			//signalMapper->setMapping(imageButton[i], text);
+			imageButton[i] = new QLabelZ (text, this);
+//			componentLayout->addWidget(imageButton[i], i / 3, i % 3, 1, 1);
 
 			QObject::connect(imageButton[i], SIGNAL(clicked()), this, SLOT(acceptS()));
 		} else {
 			if (i == 10) {
 				text = "0";
-				imageButton[i] = new QPushButton(text, this); // QIcon(":/resources/number.png"),
-				//imageButton[i] ->setFixedSize(80, 80);
-				imageButton[i] ->setContextMenuPolicy(Qt::NoContextMenu);
-				imageButton[i] ->setFocusPolicy(Qt::NoFocus);
-				imageButton[i] ->setFont(QFont ("Arial", 22, 2, false));
-				//imageButton[i] ->setIconSize(QSize(20, 20));
-				componentLayout->addWidget(imageButton[i], i / 3, i % 3, 1, 1);
+				imageButton[i] = new QLabelZ (text, this);
+//				//imageButton[i] = new QPushButton(text, this); // QIcon(":/resources/number.png"),
+//				//imageButton[i] ->setFixedSize(80, 80);
+//				imageButton[i] ->setContextMenuPolicy(Qt::NoContextMenu);
+//				imageButton[i] ->setFocusPolicy(Qt::NoFocus);
+//				imageButton[i] ->setFont(QFont ("Arial", 22, 2, false));
+//				//imageButton[i] ->setIconSize(QSize(20, 20));
+//				componentLayout->addWidget(imageButton[i], i / 3, i % 3, 1, 1);
 
 				signalMapper->setMapping(imageButton[i], text);
 
@@ -65,31 +79,41 @@ LoginDialog::LoginDialog(bool firstTime, eWallet *paTarget): QWidget((QWidget*)p
 			} else
 				if (i == 11) {
 					text = tr("Clear");
-					imageButton[i] = new QPushButton(text, this); // QIcon(":/resources/icon_clear.png"),
-					//imageButton[i] ->setFixedSize(80, 80);
-					imageButton[i] ->setContextMenuPolicy(Qt::NoContextMenu);
-					imageButton[i] ->setFocusPolicy(Qt::NoFocus);
-					imageButton[i] ->setFont(QFont ("Arial", 22, 2, false));
-					//imageButton[i] ->setIconSize(QSize(20, 20));
-					componentLayout->addWidget(imageButton[i], i / 3, i % 3, 1, 1);
+					imageButton[i] = new QLabelZ (text, this);
+//					//imageButton[i] = new QPushButton(text, this); // QIcon(":/resources/icon_clear.png"),
+//					//imageButton[i] ->setFixedSize(80, 80);
+//					imageButton[i] ->setContextMenuPolicy(Qt::NoContextMenu);
+//					imageButton[i] ->setFocusPolicy(Qt::NoFocus);
+//					imageButton[i] ->setFont(QFont ("Arial", 22, 2, false));
+//					//imageButton[i] ->setIconSize(QSize(20, 20));
+//					componentLayout->addWidget(imageButton[i], i / 3, i % 3, 1, 1);
 
 					//signalMapper->setMapping(imageButton[i], text);
 
 					QObject::connect(imageButton[i], SIGNAL(clicked()), this, SLOT(clearS()));
 				} else {
-					imageButton[i] = new QPushButton(text, this); // QIcon(":/resources/number.png"),
-					//imageButton[i] ->setFixedSize(80, 80);
-					imageButton[i] ->setContextMenuPolicy(Qt::NoContextMenu);
-					imageButton[i] ->setFocusPolicy(Qt::NoFocus);
-					imageButton[i] ->setFont(QFont ("Arial", 22, 2, false));
-					//imageButton[i] ->setIconSize(QSize(20, 20));
-					componentLayout->addWidget(imageButton[i], i / 3, i % 3, 1, 1);
+					imageButton[i] = new QLabelZ (text, this);
+//					//imageButton[i] = new QPushButton(text, this); // QIcon(":/resources/number.png"),
+//					//imageButton[i] ->setFixedSize(80, 80);
+//					imageButton[i] ->setContextMenuPolicy(Qt::NoContextMenu);
+//					imageButton[i] ->setFocusPolicy(Qt::NoFocus);
+//					imageButton[i] ->setFont(QFont ("Arial", 22, 2, false));
+//					//imageButton[i] ->setIconSize(QSize(20, 20));
+//					componentLayout->addWidget(imageButton[i], i / 3, i % 3, 1, 1);
 
 					signalMapper->setMapping(imageButton[i], text);
 
 					QObject::connect(imageButton[i], SIGNAL(clicked()), signalMapper, SLOT(map()));
 				}
 		}
+		imageButton[i]->setFrameShadow(QFrame::Raised);
+		imageButton[i]->setFrameShape(QFrame::StyledPanel);
+		imageButton[i]->setContextMenuPolicy(Qt::NoContextMenu);
+		imageButton[i]->setFocusPolicy(Qt::NoFocus);
+		imageButton[i]->setAlignment(Qt::AlignCenter);
+		imageButton[i]->setFont(QFont ("Arial", 22, 2, false));
+
+		componentLayout->addWidget(imageButton[i], i / 3, i % 3, 1, 1);
 	}
 
 	//componentLayout->addItem(new QSpacerItem(2,3), 4, 3, 3, 2);
@@ -152,17 +176,32 @@ LoginDialog::LoginDialog(bool firstTime, eWallet *paTarget): QWidget((QWidget*)p
 void LoginDialog::orientationChanged(int o) {
 	QRect screenGeometry = QApplication::desktop()->screenGeometry();
 	if (screenGeometry.width() > screenGeometry.height()) {
-		for (int i = 0; i < 12; i++) {
-			imageButton[i] ->setFont(QFont ("Arial", 22, 2, false));
-			//imageButton[i] ->setMinimumSize(70, 70);
-		}
+
+		componentLayout->setColumnMinimumWidth(3, B_SIZE);
+		componentLayout->setRowMinimumHeight(3, 0);
+
+		componentLayout->addWidget(imageButton[9], 0, 3, 1, 1);
+		componentLayout->addWidget(imageButton[10], 1, 3, 1, 1);
+		componentLayout->addWidget(imageButton[11], 2, 3, 1, 1);
+
+//		for (int i = 0; i < 12; i++) {
+//			imageButton[i] ->setFont(QFont ("Arial", 22, 2, false));
+//			//imageButton[i] ->setMinimumSize(70, 70);
+//		}
 		dlgBtnBox->show ();
 	}
 	else {
-		for (int i = 0; i < 12; i++) {
-			imageButton[i] ->setFont(QFont ("Arial", 24, 2, false));
-			//imageButton[i] ->setMinimumSize(90, 90);
-		}
+		componentLayout->setColumnMinimumWidth(3, 0);
+		componentLayout->setRowMinimumHeight(3, B_SIZE);
+
+		componentLayout->addWidget(imageButton[9], 3, 0, 1, 1);
+		componentLayout->addWidget(imageButton[10], 3, 1, 1, 1);
+		componentLayout->addWidget(imageButton[11], 3, 2, 1, 1);
+
+//		for (int i = 0; i < 12; i++) {
+//			imageButton[i] ->setFont(QFont ("Arial", 24, 2, false));
+//			//imageButton[i] ->setMinimumSize(90, 90);
+//		}
 		dlgBtnBox->hide ();
 	}
 }
