@@ -12,6 +12,20 @@
 class eWallet;
 class AboutDialog;
 
+class QLabelZ: public QLabel {
+	Q_OBJECT
+public:
+	QLabelZ(const QString &text, QWidget *parent, Qt::WindowFlags f);
+	QLabelZ(QWidget *parent, Qt::WindowFlags f);
+	~QLabelZ();
+
+signals:
+	void clicked ();
+
+protected:
+    void mousePressEvent(QMouseEvent *ev);
+};
+
 class LoginDialog : public QWidget
 {
 	Q_OBJECT
@@ -42,7 +56,9 @@ private:
 	int NTimes;
 	bool isFirstTime;
 	QString newPassword;
-	QPushButton * imageButton [12];
+	//QPushButton * imageButton [12];
+	QLabelZ * imageButton [12];
 	QLineEdit * label;
+	QGridLayout * componentLayout;
 };
 #endif // LOGINDIALOG_H
