@@ -9,10 +9,8 @@
  * TODO use hilton notifications and banner???
  * TODO check types on import
  * TODO sort after insert new card
- * TODO multilanguage
  * TODO pc version?
  * TODO fix problems with key
- * TODO rearrange view fields (for sure TEXTFIELD)
  * TODO bigger login buttons
  */
 
@@ -154,7 +152,7 @@ void eWallet::orientationChanged(int o) {
 	}
 }
 void eWallet::showList () {
-	qDebug () << "going to showList";
+	//qDebug () << "going to showList";
 
 	isAskPassword = false;
 	isChangingPassword = false;
@@ -216,10 +214,10 @@ void eWallet::showList () {
 
 	createMenu ();
 
-	//qDebug () << "setCentralWidget(centralWidget);";
+	////qDebug () << "setCentralWidget(centralWidget);";
 	setCentralWidget(centralWidget);
 
-	//qDebug () << "setFocus()";
+	////qDebug () << "setFocus()";
 	centralWidget->setFocus ();
 }
 
@@ -260,9 +258,9 @@ void eWallet::changeMode () {
 //
 //bool eWallet::event(QEvent *event)
 //{
-////	qDebug () << "EVENT " << event->type();
+////	//qDebug () << "EVENT " << event->type();
 //    if (event->type() == QEvent::Gesture) {
-//    	qDebug () << "GESTURE";
+//    	//qDebug () << "GESTURE";
 //
 //    	if (!isAskPassword) {
 //    		return gestureEvent(static_cast<QGestureEvent*>(event));
@@ -308,7 +306,7 @@ void eWallet::selectDItem(QListWidgetItem * item) {
 }
 
 void eWallet::listenInactivity(QString s) {
-	//qDebug () << "HELLO " << s;
+	////qDebug () << "HELLO " << s;
 	if (s == QString("off") && ::dbManager->isReady ()) {
 		::dbManager->lock ();
 
@@ -500,7 +498,7 @@ void eWallet::loadTypesAndFields () {
 					  this->types->append(line);
 	    		  }
 	    		  this->fieldsByType->append (new QList<TargetField>);
-				  //qDebug () << " new type "<< line << " " << this->types.length();
+				  ////qDebug () << " new type "<< line << " " << this->types.length();
 	    	  }
 	    	  else {
 	    		  int p = line.indexOf(';');
@@ -534,7 +532,7 @@ void eWallet::loadTypesAndFields () {
 	    		  else {
 	    			  this->fieldsByType->at(this->types->length() - 1)->append(TargetField (line, TYPE_STRING, true, i));
 	    		  }
-				  //qDebug () << " new field "<< line << " " << this->types.length();
+				  ////qDebug () << " new field "<< line << " " << this->types.length();
 	    	  }
 	      }
 	      else {
@@ -615,7 +613,7 @@ QPixmap eWallet::getImage (Target * target) {
 
 void eWallet::showGroups(bool reset)
 {
-	qDebug () << "show Groups " << reset;
+	//qDebug () << "show Groups " << reset;
 
 	int current = fnListWidget->currentRow();
 
@@ -671,7 +669,7 @@ void eWallet::showTargets(bool reset, const QString & filter)
 {
 	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
 
-	qDebug () << "show Targets " << reset;
+	//qDebug () << "show Targets " << reset;
 
 	int current = fnListWidget->currentRow();
 
@@ -711,7 +709,7 @@ void eWallet::showTargets(bool reset, const QString & filter)
 
 void eWallet::createMenu()
 {
-	qDebug () << "create Menu " << isAskPassword;
+	//qDebug () << "create Menu " << isAskPassword;
 
 	menuBar()->clear();
 	if (isAskPassword) {
@@ -743,7 +741,7 @@ void eWallet::sort()
 bool eWallet::__insertTarget(Target* target)
 {
 	if (::dbManager->insertTarget(target)) {
-		//qDebug () << "Adding new item";
+		////qDebug () << "Adding new item";
 		::dbManager->updateFields (target);
 		
 		target->freeFieldList();
@@ -766,14 +764,14 @@ bool eWallet::_insertTarget(Target* target)
 			QListWidgetItem* listitem = new QListWidgetItem(getImage(target), target->name, fnListWidget);
 
 			int pos = list.indexOf(target);
-			qDebug () << "position of new " << pos << " OF " << list.size ();
+			//qDebug () << "position of new " << pos << " OF " << list.size ();
 
 			if (pos < list.size()) {
-				//qDebug () << "insert position of new " << pos << " OF " << list.size ();
+				////qDebug () << "insert position of new " << pos << " OF " << list.size ();
 				fnListWidget->insertItem(pos, listitem);
 			}
 			else {
-				//qDebug () << "append position of new " << pos << " OF " << list.size ();
+				////qDebug () << "append position of new " << pos << " OF " << list.size ();
 				fnListWidget->addItem(listitem);
 			}
 			fnListWidget->setCurrentItem(listitem);
@@ -803,13 +801,13 @@ bool eWallet::_deleteTarget(Target* target)
 	if (::dbManager->deleteTarget(target)) {
 		if (isShowGroups == 2) {
 			int i = list.indexOf(target);
-			qDebug () << "DELETE ON " << i;
-			qDebug () << "trying to remove " << i;
+			//qDebug () << "DELETE ON " << i;
+			//qDebug () << "trying to remove " << i;
 			list.removeAt(i);
 
-			qDebug () << "trying to takeItem " << i;
+			//qDebug () << "trying to takeItem " << i;
 			fnListWidget->takeItem(i); //oveItem (row);
-			qDebug () << "delete " << i;
+			//qDebug () << "delete " << i;
 		}
 //		target->freeFieldList();
 //		target->freeResources();
@@ -821,7 +819,7 @@ bool eWallet::_deleteTarget(Target* target)
 }
 bool eWallet::_updateTarget(Target* target)
 {
-	//qDebug () << "UPDATE ON " << i;
+	////qDebug () << "UPDATE ON " << i;
 
 	if (::dbManager->updateTarget(target)) {
 		::dbManager->updateFields (target);
@@ -843,7 +841,7 @@ bool eWallet::_updateTarget(Target* target)
 
 bool eWallet::_updateTargetPicture(Target* target)
 {
-	//qDebug () << "UPDATE ON " << i;
+	////qDebug () << "UPDATE ON " << i;
 	if (::dbManager->updateTargetPicture(target)) {
 		if (isShowGroups == 2) {
 			int i = list.indexOf(target);
@@ -875,7 +873,7 @@ void eWallet::windowDestroyedExtra(QObject* obj) {
 	delete extraWindow;
 	extraWindow = 0;
 
-	qDebug () << "WINDOW DESTROYED YES";
+	//qDebug () << "WINDOW DESTROYED YES";
 
 	showGroups (true);
 }
@@ -1047,7 +1045,7 @@ void eWallet::import() {
 						  target->fields.append(field);
 					  }
 
-					  //qDebug () << line << " | " << line.mid(j + 1) << " IS " << line.mid (0, j);
+					  ////qDebug () << line << " | " << line.mid(j + 1) << " IS " << line.mid (0, j);
 		    	  }
 		    	  else {
 		    		  if (target != NULL && target->fields.size() > 0) {
@@ -1065,7 +1063,7 @@ void eWallet::import() {
 						imgPath += target->name.simplified().replace(' ', '_');
 						imgPath += ".png";
 
-						qDebug () << "checking image " << imgPath;
+						//qDebug () << "checking image " << imgPath;
 
 						QFile imgFile (imgPath);
 						if (imgFile.exists()) {
@@ -1082,7 +1080,7 @@ void eWallet::import() {
 						imgPath += target->name.simplified().replace(' ', '_');
 						imgPath += "_BACK.png";
 
-						qDebug () << "checking image " << imgPath;
+						//qDebug () << "checking image " << imgPath;
 
 						QFile imgFile (imgPath);
 						if (imgFile.exists()) {
@@ -1100,7 +1098,7 @@ void eWallet::import() {
 
 		      QApplication::instance()->processEvents();
 
-		      //qDebug () << line;
+		      ////qDebug () << line;
 		    }
 
 			 if (target != NULL) {
@@ -1125,7 +1123,7 @@ void eWallet::renameGroup () {
 		dialog->exec();
 		QString newName = dialog->getName();
 
-		qDebug () << "NEW GROUP NAME " << target << " TO " << newName;
+		//qDebug () << "NEW GROUP NAME " << target << " TO " << newName;
 
 		delete dialog;
 
@@ -1154,7 +1152,7 @@ void eWallet::deleteGroup () {
 }
 
 void eWallet::contextMenuEvent (QContextMenuEvent * event) {
-	//qDebug () << "Should be show " << this->childAt(event->globalPos());
+	////qDebug () << "Should be show " << this->childAt(event->globalPos());
 
 	if (isShowGroups == 1) {
 		if (fnListWidget->currentRow() > 0) {
@@ -1209,7 +1207,7 @@ void eWallet::exportData() {
 					imgPath += target->name.simplified().replace(' ', '_');
 					imgPath += ".png";
 
-					qDebug () << "exporting image " << imgPath;
+					//qDebug () << "exporting image " << imgPath;
 
 					img->save(imgPath, "PNG"); // writes image into ba in PNG format
 				}
@@ -1222,7 +1220,7 @@ void eWallet::exportData() {
 					imgPath += target->name.simplified().replace(' ', '_');
 					imgPath += "_BACK.png";
 
-					qDebug () << "exporting back image " << imgPath;
+					//qDebug () << "exporting back image " << imgPath;
 
 					img->save(imgPath, "PNG"); // writes image into ba in PNG format
 				}
